km.cutoffs <-
function(dataSet, modName="ME4", timeVar, depVar, modelType="log-rank",
                       ## modelType can equal "log-rank" or "coxph"
                       covars=NULL
                       ){
    print(paste0("Finding best cutoff for ", modName, " module with ", depVar, " outcome...")
          )
    ## Initialize results
    result <- list()
    col <- dataSet[, modName]
    dataSet$zcol1 <- (col - mean(col))/sd(col)
    protVec <- dataSet$zcol1
    best <- c(pVal=1, thresh=0)
    pVals <- c()
    threshs <- c()
    ## Test each threshold
    for(thresh in (1:nrow(dataSet))/nrow(dataSet)){
        dataSet$eigcat <- NA
        dataSet$eigcat[which(dataSet$zcol1 <   quantile(protVec, thresh))]  <- "low"
        dataSet$eigcat[which(dataSet$zcol1 >=  quantile(protVec, thresh))]  <- "high"
        if(modelType=="log-rank"){
            form1 <- as.formula(paste0("Surv(", timeVar, ",", depVar, ") ~ eigcat"))
            survdiff1  <- survdiff(form1, data=dataSet)
            pVal <- pchisq(survdiff1$chisq, length(survdiff1$n)-1,
                           lower.tail=FALSE, log.p=FALSE)
        }
        if(modelType=="coxph"){
            form2 <- as.formula( if(is.null(covars)){
                                     paste0("Surv(", timeVar, ",", depVar, ") ~ ", "eigcat")
                                 } else {
                                     paste("Surv(", timeVar, ",", depVar, ") ~ ",
                                           "eigcat", " + ", paste(covars, collapse = " + ") )
                                 })
            coxph1 <- coxph(form2, data = dataSet)
            summCoxph1 <- summary(coxph1)
            pVal <- summCoxph1$coefficients["eigcatlow","Pr(>|z|)"]

        }


        pVal <- min(pVal*4, 1)  
        pVals <- c(pVals, pVal)
        threshs <- c(threshs, thresh)

        eventTab <- table(dataSet$eigcat, dataSet[,depVar])
        eventLow  <- eventTab["low", "1"]
        eventHigh <- eventTab["high","1"]
        event10pct <- (eventLow + eventHigh)/10
        
        if(pVal< best["pVal"] & eventHigh > event10pct){
            best <- c(pVal=pVal, thresh=thresh)
            bestThresh <- thresh
            bestTab <- eventTab
        }
    }
    result[["pVals"]] <- pVals
    result[["thresholds"]] <- threshs
    result[["best"]] <- best
    result[["bestThresh"]] <- bestThresh
    result[["eventTable"]] <- bestTab
    return(result)    
}
