lin.model <-
function(depVar, indepVar, covars, Data){
    ## Fits one linear model for one module
    ## Data:A data frame with participants on rows. Covariates and  outcomes on columns.
    ##^ Row names must be unique IDs for participants.
    ## depVar: A string showing the column in Data that is the dependent variable
    ## (e.g., "total_brain_pct").
    ## indevpVar: A string showing the column in Data that is the independent variable
    ## (e.g., "ME1").
    ## Output: The summary of the model and the R-square.
    lm.dummy <- function(f1){
        if(!inherits(f1,"formula"))
            stop("f1 must inherit from call formula!"); 
        model <- lm(f1, data = Data);  
        return(model)
    }    
    result <- list()
    lmtemp <-lm.dummy(
        f1=as.formula(
            if(is.null(covars)){
                paste0(depVar, " ~ ", indepVar)
            } else {
                if(is.null(indepVar)){
                    paste(depVar, " ~ ", paste(covars, collapse = " + "))
                } else {
                    paste(
                        depVar, " ~ ", paste(indepVar, paste(
                                                           covars, collapse = " + "
                                                       ), sep=" + ")
                    )
                }
            }
        )
    )
    coefs <- summary(lmtemp)$coefficients
    if(!is.null(indepVar)){
        rownames(coefs)[2] <- indepVar}
    adj.rsq <- summary(lmtemp)$adj.r.squared
    rsq <- summary(lmtemp)$r.squared
    tvals <- summary(lmtemp)$coefficients[indepVar,"t value"]
    result[["coefs"]] <- coefs
    result[["rsq"]] <- rsq
    result[["adj.rsq"]] <- adj.rsq
    result[["tvals"]] <- tvals
    result[["resids"]] <- lmtemp$residuals
    result[["samplemod"]] <- lmtemp
    return(result)
}
