surv.models <-
function(depVar, timeVar, outData, eigSet, covars, saveAllCoefs=TRUE, label=NULL,
                        weed=FALSE, verbose=1, modelType="log-rank"){
    result <- list()
    ## make directory to store results
    dir.create(file.path(experimentPath, depVar), recursive=TRUE, showWarnings=TRUE)
    ## merge mri and protein data
    tot <- merge(eigSet,outData,by=0)
    result[["Before_excl"]] <- nrow(tot) 
    eignames <- colnames(eigSet)
    ## remove people with missing depVar
    totnarrow <- tot[, c("shareid", depVar, timeVar, eignames, covars) ]  
    result[["missingTimeVar"]] <- sum(!is.na(tot[,timeVar]))
    result[["missingDepVar"]] <- sum(!is.na(tot[,depVar]))
    ## remove people with missing vars
    totsmall <- na.omit(totnarrow)
    if(verbose>0){
        print(paste("N in", depVar, "analysis"))
        print(nrow(totsmall))}
    result[["Excl_missing"]] <- nrow(totsmall)

    ph.dummy <- function(f1){
        if(!inherits(f1,"formula"))
            stop("f1 must inherit from call formula!"); 
        model <- coxph(f1, data = totsmall);  
        return(model)
    }  
    module2coefs <- list()
    weeded <- list()
    depVarPath <- file.path(experimentPath, depVar)
    weedingPath <- file.path(depVarPath, "weeding")
    dir.create(weedingPath, recursive=TRUE, showWarnings=FALSE)

    for(col1 in colnames(eigSet)) {
        ##dir.create(file.path(experimentPath, depVar, eignames[i]), recursive=TRUE,
        ##showWarnings=TRUE)
        ##lmtemp <- coxph(Surv(tot[[timeVar]], tot[[depVar]]) ~
        ##                  tot[[eignames[i]]] + entryage + male + APOE4 + education, data=tot)
        if(verbose>1)
            print(col1)
        col <- totsmall[, col1]
        totsmall$zcol1 <- (col - mean(col))/sd(col)
        lmtemp <-ph.dummy(
            f1=as.formula(
                if(is.null(covars))
                {paste0("Surv(", timeVar, ",", depVar, ") ~ ",
                        "zcol1")}
                else {paste("Surv(", timeVar, ",", depVar, ") ~ ",
                          "zcol1", " + ", paste(covars, collapse = " + ") )
                        }
            )
        )
        phCheck <- cox.zph(lmtemp)
        write.csv(phCheck$table, file = file.path(experimentPath, depVar,
                                          paste("phCheck_", depVar, col1, ".csv", sep = "")
                                          )
                  )
        coefs <- summary(lmtemp)$coefficients
        rownames(coefs)[which(rownames(coefs)=="zcol1")] <- col1
        module2coefs[[col1]] <- coefs
        if(saveAllCoefs==TRUE){
            write.csv(coefs, file = file.path(experimentPath, depVar,
                                              paste("coefs_", depVar, col1, ".csv", sep = "")
                                              )
                      )
        }
        if(weed==TRUE){
            print(paste0("Pruning module ", col1, " for ", depVar, " outcome..."))
            if(!is.null(pigengeneFile)){
                weeded[[col1]] <- weed.proteins.surv(pigengeneFile=pigengeneFile,
                                                     depVar=depVar, timeVar=timeVar,
                                                     indepVar=col1, outData=outData,
                                                     covars=covars,
                                                     verbose=verbose-1,
                                                     outPath=file.path(weedingPath, col1))
            }
        }
        ## Add KM curves for prot quantiles:
        protVec <- totsmall$zcol1
        if(col1=="ME2" | col1=="ME4"){
            thresholds <- km.cutoffs(dataSet=totsmall, modName=col1, timeVar=timeVar, depVar=depVar,
                                     modelType=modelType, covars=covars)
            result[[paste0(col1, "_thresholds")]] <- thresholds
            bestThresh <- thresholds$bestThresh
            totsmall$eigcat <- NA
            totsmall$eigcat[which(totsmall$zcol1 <   quantile(protVec, bestThresh))]  <- "low"
            totsmall$eigcat[which(totsmall$zcol1 >=  quantile(protVec, bestThresh))]  <- "high"

            form1 <- as.formula(paste0("Surv(", timeVar, ",", depVar, ") ~ eigcat"))
            km <- do.call(survfit, args = list(formula = form1, data = totsmall))

            if(col1=="ME2")
                hiLoLabs<-c("High M2", "Low M2")
            if(col1=="ME4")
                hiLoLabs<-c("High M4", "Low M4")
            
            bestPH <- ph.dummy(
                f1=as.formula(
                    if(is.null(covars))
                    {paste0("Surv(", timeVar, ",", depVar, ") ~ ",
                            "eigcat")}
                    else {paste("Surv(", timeVar, ",", depVar, ") ~ ",
                                "eigcat", " + ", paste(covars, collapse = " + ") )
                            }
                )
            )
            kmplot <- ggsurvplot(km, data = totsmall,
                                 pval = paste0("Adjusted p-value: p=",
                                               round(thresholds$best["pVal"],3)),
                                 legend.labs=hiLoLabs)
            ggsave(file.path(depVarPath, paste0(col1, "_", depVar, "best.png")), print(kmplot),
                   dpi=600)
        } # plot km        
    } # col (protein)    
    result[["coefs"]] <- module2coefs
    result[["samplemod"]] <- lmtemp
    result[["weeded"]] <- weeded
    models <- result
    save(models, file=file.path(depVarPath, paste(depVar, label, "models.RData", sep="_")))
    cat("\n\n Survival results saved at:\n")
    cat(file.path(experimentPath, depVar), "\n")
    return(result)
}
